
REM This script is used to generate the root certificate authority (rootCA.pem) and
REM web page certificate(server.pem).

REM 
REM NOTE Command Prompt must be ran from same directory as openssl.exe
REM openssl.exe is located in bin folder of OpenSSL root directory
REM e.g.: C:\OpenSSl-Win64\bin
REM 
@echo off
set OPENSSLCONFIG="[Path to openssl.cnf]\openssl.cnf"
REM e.g.: OPENSSLCONFIG="C:\Users\sbtadmin\Downloads\openssl-1.1.1c-win64-mingw\openssl-1.1.1c-win64-mingw\openssl.cnf"
REM 
REM Generate private key (server.key) for our server.
REM 
openssl genrsa -out server.key 2048

REM 
REM Create a certificate signing request (server.csr) for the CA to sign.
REM 
REM NOTE that the Common Name (CN) specified in this step should be 127.0.0.1, or the
REM CN must match the wss address used by the app.
REM 
REM NOTE used values as of 05/01/2017
REM    Country Name: US
REM    State:        Florida
REM    Locality:     Pensacola
REM    Organization: Example Company
REM    Unit Name:    EC
REM    Common Name:  127.0.0.1
REM    Email:        support@examplecompany.com
REM 
REM 
REM No values for 'extra' attributes
REM 
openssl req -config "%OPENSSLCONFIG%" -sha256 -new -key server.key -out server.csr

REM 
REM Create root key (rootCA.key).
REM 
openssl genrsa -out rootCA.key 2048

REM 
REM Sign the CA, creating rootCA.pem.
REM 
REM NOTE that the CN specified in this step should be a FQDN; e.g.: www.xyz.com
REM 
REM NOTE use values that were used for server.csr (commented above) except for the CN
REM 
openssl req -config "%OPENSSLCONFIG%" -x509 -sha256 -new -nodes -key rootCA.key -days 825 -out rootCA.pem

REM 
REM Create the server digital cert (server.crt) with the root signature.
REM 
REM Add the extension file 'v3.ext' to the working directory.
REM Include this ext file to add 'subjectAltName' with a value of 127.0.0.1. 
REM See Silver Bullet Case 28744: Chrome no longser supports the Common Name (CN)
REM 
openssl x509 -req -sha256 -in server.csr -CA rootCA.pem -CAkey rootCA.key -CAcreateserial -out server.crt -days 825 -extfile v3.ext

REM 
REM Create server.rsa.key file.
REM 
openssl rsa -in server.key -out server.rsa.key

REM 
REM Create the server.pem cert (will contain just the cert at this point).
REM 
REM NOTE cp is a unix command
REM For windows use 'copy'
REM 
REM e.g.: copy server.crt server.pem
REM 
copy server.crt server.pem

REM 
REM Concatenate the key into the server.pem cert so the final server.pem file
REM contains *both* the cert and the key.
REM 
REM 
type server.rsa.key >> server.pem
