#!/bin/bash
#
#createfile.sh
#This script is used to generate the root certificate authority (rootCA.cer) and
#web page certificate(server.pem).
#
#
#
#Generate private key (server.key) for our server.
#
openssl genrsa -out server.key 2048
#
#
#Create a certificate signing request (server.csr) for the CA to sign.
#
#NOTE that the Common Name (CN) specified in this step should be 127.0.0.1, or the
#CN must match the wss address used by the app.
#
#NOTE EXAMPLE ONLY
#   Country Name: US
#   State:        Florida
#   Locality:     Pensacola
#   Organization: Example Company, Inc.
#   Unit Name:    EC
#   Common Name:  127.0.0.1
#   Email:        support@examplecompany.com
#
#
#No values for 'extra' attributes
#
openssl req -sha256 -new -key server.key -out server.csr
#
#
#Create root key (rootCA.key).
#
openssl genrsa -out rootCA.key 2048
#
#
#Sign the CA, creating rootCA.cer.
#
#NOTE that the CN specified in this step should be a FQDN; e.g.: www.xyz.com
#
#NOTE use values that were used for server.csr (commented above) except for the CN
#NOTE As of March 1st 2018 new SSL certificates will be restricted to 825 days.
#
openssl req -x509 -sha256 -new -nodes -key rootCA.key -days 825 -out rootCA.cer
#
#
#Create the server digital cert (server.crt) with the root signature.
#
#Add the extension file 'v3.ext' to the working directory.
#Include this ext file to add 'subjectAltName' with a value of 127.0.0.1. 
#See Silver Bullet Case# 28744: Chrome no longer supports the Common Name (CN)
#
openssl x509 -req -sha256 -in server.csr -CA rootCA.cer -CAkey rootCA.key -CAcreateserial -out server.crt -days 825 -extfile ./v3.ext
#
#
#Create server.rsa.key file.
#
openssl rsa -in server.key -out server.rsa.key
#
#
#Create the server.pem cert (will contain just the cert at this point).
#
#
cp server.crt server.pem
#
#
#Concatenate the key into the server.pem cert so the final server.pem file
#contains *both* the cert and the key.
#
cat server.rsa.key >> server.pem
#